==> react-amplify-wrapper-1.0.10.tgz: package/actions/creators.ts <==
import { IChangeAttributes, IChangePassword, IConfirmSignUp, IForgotPassword, IForgotPasswordSubmit, IResendConfirmationCode, ISignIn, ISignOut, ISignUp, ISignUpAction } from './interfaces'
import { AUTH_ACTION_TYPES } from './types'

export function signUpAction({ email, password, firstName, lastName}: ISignUpAction): ISignUp  {
    return { type: AUTH_ACTION_TYPES.SIGN_UP, email, password, firstName, lastName }
}

export function confirmSignUpAction(confirmationCode: string, email?: string): IConfirmSignUp {
    return { type: AUTH_ACTION_TYPES.CONFIRM_SIGN_UP, confirmationCode, email }
}

export function resendConfirmationCodeAction(email: string): IResendConfirmationCode {
    return { type: AUTH_ACTION_TYPES.RESEND_CONFIRMATION_CODE, email }
}

export function signInAction(email: string, password: string): ISignIn {
    return { type: AUTH_ACTION_TYPES.SIGN_IN, email, password }
}

export function signOutAction(): ISignOut {
    return { type: AUTH_ACTION_TYPES.SIGN_OUT}
}

export function forgotPasswordAction(email: string): IForgotPassword {
    return { type: AUTH_ACTION_TYPES.FORGOT_PASSWORD, email}
}

export function forgotPasswordSubmitAction(code: string, newPassword: string): IForgotPasswordSubmit {
    return { type: AUTH_ACTION_TYPES.FORGOT_PASSWORD_SUBMIT, code, newPassword}
}

export function changePasswordAction(oldPassword: string, newPassword: string): IChangePassword {
    return { type: AUTH_ACTION_TYPES.CHANGE_PASSWORD, oldPassword, newPassword}
}

export function changeAttributesAction(name: string, email: string): IChangeAttributes {
    return { type: AUTH_ACTION_TYPES.CHANGE_ATTRIBUTES, name, email}
}

==> react-amplify-wrapper-1.0.14.tgz: package/actions/creators.ts <==
import { IChangeAttributes, IChangePassword, IConfirmSignUp, IForgotPassword, IForgotPasswordSubmit, IResendConfirmationCode, ISignIn, ISignOut, ISignUp, ISignUpAction } from './interfaces'
import { AUTH_ACTION_TYPES } from './types'

export function signUpAction({ email, password, firstName, lastName}: ISignUpAction): ISignUp  {
    return { type: AUTH_ACTION_TYPES.SIGN_UP, email, password, firstName, lastName }
}

export function confirmSignUpAction(confirmationCode: string, email?: string): IConfirmSignUp {
    return { type: AUTH_ACTION_TYPES.CONFIRM_SIGN_UP, confirmationCode, email }
}

export function resendConfirmationCodeAction(email: string): IResendConfirmationCode {
    return { type: AUTH_ACTION_TYPES.RESEND_CONFIRMATION_CODE, email }
}

export function signInAction(email: string, password: string): ISignIn {
    return { type: AUTH_ACTION_TYPES.SIGN_IN, email, password }
}

export function signOutAction(): ISignOut {
    return { type: AUTH_ACTION_TYPES.SIGN_OUT}
}

export function forgotPasswordAction(email: string): IForgotPassword {
    return { type: AUTH_ACTION_TYPES.FORGOT_PASSWORD, email}
}

export function forgotPasswordSubmitAction(code: string, newPassword: string, email?: string): IForgotPasswordSubmit {
    return { type: AUTH_ACTION_TYPES.FORGOT_PASSWORD_SUBMIT, code, newPassword, email}
}

export function changePasswordAction(oldPassword: string, newPassword: string): IChangePassword {
    return { type: AUTH_ACTION_TYPES.CHANGE_PASSWORD, oldPassword, newPassword}
}

export function changeAttributesAction(name: string, email: string): IChangeAttributes {
    return { type: AUTH_ACTION_TYPES.CHANGE_ATTRIBUTES, name, email}
}
